fars_map_state: Create a map visualising all accident events in a given State...

Description Usage Arguments Details Value Examples

Description

This function takes a State number (state.num) indicator and a year (year).

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

a State Code Number as Integer

year

a given Year as Integer

Details

If the State number does not exhist in the data for the given year, the method exits (STOP) with a message "invalid STATE number: ???".

If no data for State Num / year combination a message "no accidents to plot" is returned.

Value

This function returns a character vector the format "accident_YEAR.csv.bz2"

Examples

1
2
3
4
## Not run: 
fars_map_state(12, 2017)

## End(Not run)

yenlaw/yenlaw_farsfunctions documentation built on May 8, 2019, 5:49 p.m.