fars_read: Verify if the file exists using the 'filename' function

Description Usage Arguments Value Examples

Description

Verify if the file exists using the filename function

Usage

1
fars_read(filename)

Arguments

filename

the name of the file; provided as character string.

Value

dataframe representation of the file contents defined filename or 'does not exist' message.

Examples

1
2
3
4
5
## Not run: 
fars_read("filename.csv")
fars_read("path/filename.csv")

## End(Not run)

yenlaw/yenlaw_farsfunctions documentation built on May 8, 2019, 5:49 p.m.