fars_read_years: Read multiple .csv data file for a series a provided years

Description Usage Arguments Details Value Examples

Description

This function take as input a vector of integers (years); returns a list collection of DataFrames of Years and respesctive months.

Usage

1

Arguments

years

A vector of integers representing a series of years

Details

For each year with no data file, the function generates a warning message.

Value

This function returns a dataframe with Year and Months columns for each year.

Examples

1
2
3
4
5
## Not run: 
fars_read_years(2017)
fars_read_years(2015:2016)

## End(Not run)

yenlaw/yenlaw_farsfunctions documentation built on May 8, 2019, 5:49 p.m.