Description Usage Arguments Details Value Examples
This function takes a collection of years (years) as input and returns a Tibble(Data Frame)
containing the defined data summary as a Wide Format.
1 | fars_summarize_years(years)
|
years |
A list of years given as integers. |
For each year with no data file, the function generates a warning message.
This function returns a dataframe with Year and Months columns for each year.
1 2 3 4 5 | ## Not run:
fars_summarize_years(2017)
fars_summarize_years(2015:2016)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.