make_filename: Create a filename for a given year with format...

Description Usage Arguments Value Examples

Description

This function print a character vector with the filename combining the default file name and the year passed as argument to the function

Usage

1

Arguments

year

of file creation as integer / string.

Value

This function returns a character vector the format "accident_YEAR.csv.bz2"

Examples

1
2
3
4
## Not run: 
make_filename(2017)

## End(Not run)

yenlaw/yenlaw_farsfunctions documentation built on May 8, 2019, 5:49 p.m.