Description Usage Arguments Details Value Examples
This function takes a State number (state.num) indicator and a year (year).
1 | fars_map_state(state.num, year)
|
state.num |
a State Code Number as Integer |
year |
a given Year as Integer |
If the State number does not exhist in the data for the given year, the method exits (STOP) with a message "invalid STATE number: ???".
If no data for State Num / year combination a message "no accidents to plot" is returned.
This function returns a character vector the format "accident_YEAR.csv.bz2"
1 2 3 4 | ## Not run:
fars_map_state(12, 2017)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.