Description Usage Arguments Value Examples
Verify if the file exists using the filename function
1 | fars_read(filename)
|
filename |
the name of the file; provided as character string. |
dataframe representation of the file contents defined filename or 'does not exist' message.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.