Description Usage Arguments Details Value Examples
This function take as input a vector of integers (years); returns a list collection of
DataFrames of Years and respesctive months.
1 | fars_read_years(years)
|
years |
A vector of integers representing a series of years |
For each year with no data file, the function generates a warning message.
This function returns a dataframe with Year and Months columns for each year.
1 2 3 4 5 | ## Not run:
fars_read_years(2017)
fars_read_years(2015:2016)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.