Description Usage Arguments Value Examples
This function print a character vector with the filename combining the default
file name and the year passed as argument to the function
1 | make_filename(year)
|
year |
of file creation as integer / string. |
This function returns a character vector the format "accident_YEAR.csv.bz2"
1 2 3 4 | ## Not run:
make_filename(2017)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.